/*
 * Copyright (C) 2008  Remko Troncon
 * See COPYING file for the detailed license.
 */

#include "AutoUpdater.h"

AutoUpdater::~AutoUpdater() = default;
